@@ -21,9 +21,11 @@ from .base import BasePredictor
 from inference.transforms import ZoomIn
 
 
-def get_predictor(
-    net, brs_mode, with_flip=False, zoom_in_params=dict(), predictor_params=None
-):
+def get_predictor(net,
+                  brs_mode,
+                  with_flip=False,
+                  zoom_in_params=dict(),
+                  predictor_params=None):
 
     predictor_params_ = {"optimize_after_n_clicks": 1}
 
@@ -37,8 +39,7 @@ def get_predictor(
         if predictor_params is not None:
             predictor_params_.update(predictor_params)
         predictor = BasePredictor(
-            net, zoom_in=zoom_in, with_flip=with_flip, **predictor_params_
-        )
+            net, zoom_in=zoom_in, with_flip=with_flip, **predictor_params_)
 
     else:
         raise NotImplementedError("Just support NoBRS mode")
