@@ -12,5 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-from .grid import Grids
\ No newline at end of file
+from .rs_grid import RSGrids
+from .grid import Grids, checkOpenGrid
\ No newline at end of file
