@@ -29,8 +29,8 @@ class COCO:
             "categories": [],
             "images": [],
             "annotations": [],
-            "info": "info",
-            "licenses": "licenses",
+            "info": "",
+            "licenses": [],
         }  # the complete json
         self.anns = dict()  # anns[annId]={}
         self.cats = dict()  # cats[catId] = {}
@@ -40,7 +40,7 @@ class COCO:
         self.imgNameToId = defaultdict(list)  # imgNameToId[name] = imgId
         self.maxAnnId = 0
         self.maxImgId = 0
-        if annotation_file is not None:
+        if annotation_file is not None and os.path.exists(annotation_file):
             print("loading annotations into memory...")
             tic = time.time()
             dataset = json.load(open(annotation_file, "r"))
@@ -103,14 +103,13 @@ class COCO:
         self.cats = cats
 
     def setInfo(
-        self,
-        year: int = "",
-        version: str = "",
-        description: str = "",
-        contributor: str = "",
-        url: str = "",
-        date_created: datetime = "",
-    ):
+            self,
+            year: int="",
+            version: str="",
+            description: str="",
+            contributor: str="",
+            url: str="",
+            date_created: datetime="", ):
         self.dataset["info"] = {
             "year": year,
             "version": version,
@@ -121,12 +120,11 @@ class COCO:
         }
 
     def addCategory(
-        self,
-        id: int,
-        name: str,
-        color: list,
-        supercategory: str = "",
-    ):
+            self,
+            id: int,
+            name: str,
+            color: list,
+            supercategory: str="", ):
         cat = {
             "id": id,
             "name": name,
@@ -137,12 +135,11 @@ class COCO:
         self.dataset["categories"].append(cat)
 
     def updateCategory(
-        self,
-        id: int,
-        name: str,
-        color: list,
-        supercategory: str = "",
-    ):
+            self,
+            id: int,
+            name: str,
+            color: list,
+            supercategory: str="", ):
         cat = {
             "id": id,
             "name": name,
@@ -155,16 +152,15 @@ class COCO:
                 self.dataset["categories"][idx] = cat
 
     def addImage(
-        self,
-        file_name: str,
-        width: int,
-        height: int,
-        id: int = None,
-        license: int = "",
-        flickr_url: str = "",
-        coco_url: str = "",
-        date_captured: datetime = "",
-    ):
+            self,
+            file_name: str,
+            width: int,
+            height: int,
+            id: int=None,
+            license: int="",
+            flickr_url: str="",
+            coco_url: str="",
+            date_captured: datetime="", ):
         if self.hasImage(file_name):
             print(f"{file_name}图片已存在")
             return
@@ -186,36 +182,40 @@ class COCO:
         self.imgNameToId[file_name] = id
         return id
 
+    def getBB(self, segmentation):
+        x = segmentation[::2]
+        y = segmentation[1::2]
+        maxx, minx, maxy, miny = max(x), min(x), max(y), min(y)
+        return [minx, miny, maxx - minx, maxy - miny]
+
+    def getArea(self, segmentation):
+        x = segmentation[::2]
+        y = segmentation[1::2]
+
+        return 0.5 * np.abs(np.dot(x, np.roll(y, 1)) - np.dot(y, np.roll(x, 1)))
+
     def addAnnotation(
-        self,
-        image_id: int,
-        category_id: int,
-        segmentation: list,
-        bbox: list = None,
-        area: float = None,
-        id: int = None,
-    ):
+            self,
+            image_id: int,
+            category_id: int,
+            segmentation: list,
+            area: float=None,
+            id: int=None, ):
         if id is not None and self.anns.get(id, None) is not None:
             print("标签已经存在")
             return
         if not id:
             self.maxAnnId += 1
             id = self.maxAnnId
-        if not bbox:
-            x, y, width, height = 0, 0, 0, 0
-        else:
-            x, y, width, height = bbox[:]
-        # TODO: cal area
-        if not area:
-            area = 0
 
         ann = {
             "id": id,
+            "iscrowd": 0,
             "image_id": image_id,
             "category_id": category_id,
             "segmentation": [segmentation],
-            "area": area,
-            "bbox": [x, y, width, height],
+            "area": self.getArea(segmentation),
+            "bbox": self.getBB(segmentation),
         }
 
         self.dataset["annotations"].append(ann)
@@ -236,14 +236,13 @@ class COCO:
             if ann["id"] == annId:
                 del self.imgToAnns[imgId][idx]
 
-    def updateAnnotation(self, id, imgId, points, bbox=None):
-        self.anns[id]["segmentation"] = [points]
-
+    def updateAnnotation(self, id, imgId, segmentation):
+        self.anns[id]["segmentation"] = [segmentation]
+        self.anns[id]["bbox"] = self.getBB(segmentation)
+        self.anns[id]["area"] = self.getArea(segmentation)
         for rec in self.dataset["annotations"]:
             if rec["id"] == id:
-                rec["segmentation"] = [points]
-                if bbox is not None:
-                    rec["bbox"] = bbox
+                rec = self.anns[id]
                 break
 
         for rec in self.dataset["annotations"]:
@@ -252,13 +251,12 @@ class COCO:
                 print(
                     "record point : ",
                     rec["segmentation"][0][0],
-                    rec["segmentation"][0][1],
-                )
+                    rec["segmentation"][0][1], )
                 break
 
         for rec in self.imgToAnns[imgId]:
             if rec["id"] == id:
-                rec["segmentation"] = [points]
+                rec["segmentation"] = [segmentation]
                 break
 
     def info(self):
@@ -286,25 +284,18 @@ class COCO:
         else:
             if not len(imgIds) == 0:
                 lists = [
-                    self.imgToAnns[imgId] for imgId in imgIds if imgId in self.imgToAnns
+                    self.imgToAnns[imgId] for imgId in imgIds
+                    if imgId in self.imgToAnns
                 ]
                 anns = list(itertools.chain.from_iterable(lists))
             else:
                 anns = self.dataset["annotations"]
-            anns = (
-                anns
-                if len(catIds) == 0
-                else [ann for ann in anns if ann["category_id"] in catIds]
-            )
-            anns = (
-                anns
-                if len(areaRng) == 0
-                else [
-                    ann
-                    for ann in anns
-                    if ann["area"] > areaRng[0] and ann["area"] < areaRng[1]
-                ]
-            )
+            anns = (anns if len(catIds) == 0 else
+                    [ann for ann in anns if ann["category_id"] in catIds])
+            anns = (anns if len(areaRng) == 0 else [
+                ann for ann in anns
+                if ann["area"] > areaRng[0] and ann["area"] < areaRng[1]
+            ])
         if not iscrowd == None:
             ids = [ann["id"] for ann in anns if ann["iscrowd"] == iscrowd]
         else:
@@ -327,21 +318,12 @@ class COCO:
             cats = self.dataset["categories"]
         else:
             cats = self.dataset["categories"]
-            cats = (
-                cats
-                if len(catNms) == 0
-                else [cat for cat in cats if cat["name"] in catNms]
-            )
-            cats = (
-                cats
-                if len(supNms) == 0
-                else [cat for cat in cats if cat["supercategory"] in supNms]
-            )
-            cats = (
-                cats
-                if len(catIds) == 0
-                else [cat for cat in cats if cat["id"] in catIds]
-            )
+            cats = (cats if len(catNms) == 0 else
+                    [cat for cat in cats if cat["name"] in catNms])
+            cats = (cats if len(supNms) == 0 else
+                    [cat for cat in cats if cat["supercategory"] in supNms])
+            cats = (cats if len(catIds) == 0 else
+                    [cat for cat in cats if cat["id"] in catIds])
         ids = [cat["id"] for cat in cats]
         return ids
 
@@ -584,9 +566,8 @@ class COCO:
             fname = os.path.join(tarDir, img["file_name"])
             if not os.path.exists(fname):
                 urlretrieve(img["coco_url"], fname)
-            print(
-                "downloaded {}/{} images (t={:0.1f}s)".format(i, N, time.time() - tic)
-            )
+            print("downloaded {}/{} images (t={:0.1f}s)".format(
+                i, N, time.time() - tic))
 
     def loadNumpyAnnotations(self, data):
         """
@@ -603,14 +584,12 @@ class COCO:
         for i in range(N):
             if i % 1000000 == 0:
                 print("{}/{}".format(i, N))
-            ann += [
-                {
-                    "image_id": int(data[i, 0]),
-                    "bbox": [data[i, 1], data[i, 2], data[i, 3], data[i, 4]],
-                    "score": data[i, 5],
-                    "category_id": int(data[i, 6]),
-                }
-            ]
+            ann += [{
+                "image_id": int(data[i, 0]),
+                "bbox": [data[i, 1], data[i, 2], data[i, 3], data[i, 4]],
+                "score": data[i, 5],
+                "category_id": int(data[i, 6]),
+            }]
         return ann
 
     # def annToRLE(self, ann):
