@@ -17,6 +17,7 @@ from enum import Enum
 import cv2
 import numpy as np
 import math
+from .regularization import boundary_regularization
 
 
 class Instructions(Enum):
@@ -24,10 +25,10 @@ class Instructions(Enum):
     Polygon_Instruction = 1
 
 
-def get_polygon(label, sample="Dynamic"):
+def get_polygon(label, sample="Dynamic", building=False):
     results = cv2.findContours(
-        image=label, mode=cv2.RETR_TREE, method=cv2.CHAIN_APPROX_TC89_KCOS
-    )  # 获取内外边界，用RETR_TREE更好表示
+        image=label, mode=cv2.RETR_TREE,
+        method=cv2.CHAIN_APPROX_TC89_KCOS)  # 获取内外边界，用RETR_TREE更好表示
     cv2_v = cv2.__version__.split(".")[0]
     contours = results[1] if cv2_v == "3" else results[0]  # 边界
     hierarchys = results[2] if cv2_v == "3" else results[1]  # 隶属信息
@@ -35,27 +36,27 @@ def get_polygon(label, sample="Dynamic"):
         polygons = []
         relas = []
         img_shape = label.shape
-        for idx, (contour, hierarchy) in enumerate(zip(contours, hierarchys[0])):
+        for idx, (contour,
+                  hierarchy) in enumerate(zip(contours, hierarchys[0])):
             # print(hierarchy)
             # opencv实现边界简化
-            epsilon = (
-                0.0005 * cv2.arcLength(contour, True) if sample == "Dynamic" else sample
-            )
+            epsilon = (0.005 * cv2.arcLength(contour, True)
+                       if sample == "Dynamic" else sample)
             if not isinstance(epsilon, float) and not isinstance(epsilon, int):
                 epsilon = 0
             # print("epsilon:", epsilon)
-            out = cv2.approxPolyDP(contour, epsilon, True)  # 自然图像简化
-            # 自定义边界简化
-            """
-                TODO: 内圈太简单有可能简化没有了，造成下面的索引超出界限，
-                      目前会筛选掉这些空内圈避免错误
-            """
-            out = approx_poly_DP(out)
+            if building is False:
+                # -- Douglas-Peucker算法边界简化
+                contour = cv2.approxPolyDP(contour, epsilon / 10, True)
+            else:
+                # -- 建筑边界简化（https://github.com/niecongchong/RS-building-regularization）
+                contour = boundary_regularization(contour, img_shape, epsilon)
+            # -- 自定义（角度和距离）边界简化
+            out = approx_poly_DIY(contour)
             # 给出关系
             rela = (
                 idx,  # own
-                hierarchy[-1] if hierarchy[-1] != -1 else None,
-            )  # parent
+                hierarchy[-1] if hierarchy[-1] != -1 else None, )  # parent
             polygon = []
             for p in out:
                 polygon.append(p[0])
@@ -66,7 +67,8 @@ def get_polygon(label, sample="Dynamic"):
                 for j in range(len(relas)):
                     if relas[j][0] == relas[i][1]:  # i的父圈就是j（i是j的子圈）
                         if polygons[i] is not None and polygons[j] is not None:
-                            min_i, min_o = __find_min_point(polygons[i], polygons[j])
+                            min_i, min_o = __find_min_point(polygons[i],
+                                                            polygons[j])
                             # 改变顺序
                             polygons[i] = __change_list(polygons[i], min_i)
                             polygons[j] = __change_list(polygons[j], min_o)
@@ -97,9 +99,8 @@ def __find_min_point(i_list, o_list):
     idx_o = -1
     for i in range(len(i_list)):
         for o in range(len(o_list)):
-            dis = math.sqrt(
-                (i_list[i][0] - o_list[o][0]) ** 2 + (i_list[i][1] - o_list[o][1]) ** 2
-            )
+            dis = math.sqrt((i_list[i][0] - o_list[o][0])**2 + (i_list[i][
+                1] - o_list[o][1])**2)
             if dis <= min_dis:
                 min_dis = dis
                 idx_i = i
@@ -110,38 +111,27 @@ def __find_min_point(i_list, o_list):
 # 根据三点坐标计算夹角
 def __cal_ang(p1, p2, p3):
     eps = 1e-12
-    a = math.sqrt((p2[0] - p3[0]) * (p2[0] - p3[0]) + (p2[1] - p3[1]) * (p2[1] - p3[1]))
-    b = math.sqrt((p1[0] - p3[0]) * (p1[0] - p3[0]) + (p1[1] - p3[1]) * (p1[1] - p3[1]))
-    c = math.sqrt((p1[0] - p2[0]) * (p1[0] - p2[0]) + (p1[1] - p2[1]) * (p1[1] - p2[1]))
-    ang = math.degrees(
-        math.acos((b ** 2 - a ** 2 - c ** 2) / (-2 * a * c + eps))
-    )  # p2对应
+    a = math.sqrt((p2[0] - p3[0]) * (p2[0] - p3[0]) + (p2[1] - p3[1]) * (p2[1] -
+                                                                         p3[1]))
+    b = math.sqrt((p1[0] - p3[0]) * (p1[0] - p3[0]) + (p1[1] - p3[1]) * (p1[1] -
+                                                                         p3[1]))
+    c = math.sqrt((p1[0] - p2[0]) * (p1[0] - p2[0]) + (p1[1] - p2[1]) * (p1[1] -
+                                                                         p2[1]))
+    ang = math.degrees(math.acos(
+        (b**2 - a**2 - c**2) / (-2 * a * c + eps)))  # p2对应
     return ang
 
 
 # 计算两点距离
 def __cal_dist(p1, p2):
-    return math.sqrt((p1[0] - p2[0]) ** 2 + (p1[1] - p2[1]) ** 2)
+    return math.sqrt((p1[0] - p2[0])**2 + (p1[1] - p2[1])**2)
 
 
 # 边界点简化
-def approx_poly_DP(contour, min_dist=10, ang_err=5):
+def approx_poly_DIY(contour, min_dist=10, ang_err=5):
     # print(contour.shape)  # N, 1, 2
     cs = [contour[i][0] for i in range(contour.shape[0])]
-    ## 1. 先删除夹角接近180度的点
-    i = 0
-    while i < len(cs):
-        try:
-            last = (i - 1) if (i != 0) else (len(cs) - 1)
-            next = (i + 1) if (i != len(cs) - 1) else 0
-            ang_i = __cal_ang(cs[last], cs[i], cs[next])
-            if abs(ang_i) > (180 - ang_err):
-                del cs[i]
-            else:
-                i += 1
-        except:
-            i += 1
-    ## 2. 再删除两个相近点与前后两个点角度接近的点
+    ## 1. 先删除两个相近点与前后两个点角度接近的点
     i = 0
     while i < len(cs):
         try:
@@ -154,8 +144,10 @@ def approx_poly_DP(contour, min_dist=10, ang_err=5):
                 # print(ang_i, ang_j)  # 角度值为-180到+180
                 if abs(ang_i - ang_j) < ang_err:
                     # 删除距离两点小的
-                    dist_i = __cal_dist(cs[last], cs[i]) + __cal_dist(cs[i], cs[next])
-                    dist_j = __cal_dist(cs[last], cs[j]) + __cal_dist(cs[j], cs[next])
+                    dist_i = __cal_dist(cs[last], cs[i]) + __cal_dist(cs[i],
+                                                                      cs[next])
+                    dist_j = __cal_dist(cs[last], cs[j]) + __cal_dist(cs[j],
+                                                                      cs[next])
                     if dist_j < dist_i:
                         del cs[j]
                     else:
@@ -166,5 +158,19 @@ def approx_poly_DP(contour, min_dist=10, ang_err=5):
                 i += 1
         except:
             i += 1
+    ## 2. 再删除夹角接近180度的点
+    i = 0
+    while i < len(cs):
+        try:
+            last = (i - 1) if (i != 0) else (len(cs) - 1)
+            next = (i + 1) if (i != len(cs) - 1) else 0
+            ang_i = __cal_ang(cs[last], cs[i], cs[next])
+            if abs(ang_i) > (180 - ang_err):
+                del cs[i]
+            else:
+                i += 1
+        except:
+            # i += 1
+            del cs[i]
     res = np.array(cs).reshape([-1, 1, 2])
     return res
