@@ -4,9 +4,11 @@ import cv2
 import numpy as np
 
 
-def visualize_instances(
-    imask, bg_color=255, boundaries_color=None, boundaries_width=1, boundaries_alpha=0.8
-):
+def visualize_instances(imask,
+                        bg_color=255,
+                        boundaries_color=None,
+                        boundaries_width=1,
+                        boundaries_alpha=0.8):
     num_objects = imask.max() + 1
     palette = get_palette(num_objects)
     if bg_color is not None:
@@ -14,7 +16,8 @@ def visualize_instances(
 
     result = palette[imask].astype(np.uint8)
     if boundaries_color is not None:
-        boundaries_mask = get_boundaries(imask, boundaries_width=boundaries_width)
+        boundaries_mask = get_boundaries(
+            imask, boundaries_width=boundaries_width)
         tresult = result.astype(np.float32)
         tresult[boundaries_mask] = boundaries_color
         tresult = tresult * boundaries_alpha + (1 - boundaries_alpha) * result
@@ -35,12 +38,14 @@ def visualize_mask(mask, num_cls):
     return palette[mask].astype(np.uint8)
 
 
-def visualize_proposals(proposals_info, point_color=(255, 0, 0), point_radius=1):
+def visualize_proposals(proposals_info, point_color=(255, 0, 0),
+                        point_radius=1):
     proposal_map, colors, candidates = proposals_info
 
     proposal_map = draw_probmap(proposal_map)
     for x, y in candidates:
-        proposal_map = cv2.circle(proposal_map, (y, x), point_radius, point_color, -1)
+        proposal_map = cv2.circle(proposal_map, (y, x), point_radius,
+                                  point_color, -1)
 
     return proposal_map
 
@@ -76,8 +81,7 @@ def blend_mask(image, mask, alpha=0.6):
 
 def get_boundaries(instances_masks, boundaries_width=1):
     boundaries = np.zeros(
-        (instances_masks.shape[0], instances_masks.shape[1]), dtype=np.bool
-    )
+        (instances_masks.shape[0], instances_masks.shape[1]), dtype=np.bool)
 
     for obj_id in np.unique(instances_masks.flatten()):
         if obj_id == 0:
@@ -86,24 +90,24 @@ def get_boundaries(instances_masks, boundaries_width=1):
         obj_mask = instances_masks == obj_id
         kernel = cv2.getStructuringElement(cv2.MORPH_ELLIPSE, (3, 3))
         inner_mask = cv2.erode(
-            obj_mask.astype(np.uint8), kernel, iterations=boundaries_width
-        ).astype(np.bool)
+            obj_mask.astype(np.uint8), kernel,
+            iterations=boundaries_width).astype(np.bool)
 
-        obj_boundary = np.logical_xor(obj_mask, np.logical_and(inner_mask, obj_mask))
+        obj_boundary = np.logical_xor(obj_mask,
+                                      np.logical_and(inner_mask, obj_mask))
         boundaries = np.logical_or(boundaries, obj_boundary)
     return boundaries
 
 
 def draw_with_blend_and_clicks(
-    img,
-    mask=None,
-    alpha=0.6,
-    clicks_list=None,
-    pos_color=(0, 255, 0),
-    neg_color=(255, 0, 0),
-    radius=4,
-    palette=None,
-):
+        img,
+        mask=None,
+        alpha=0.6,
+        clicks_list=None,
+        pos_color=(0, 255, 0),
+        neg_color=(255, 0, 0),
+        radius=4,
+        palette=None, ):
     result = img.copy()
 
     if mask is not None:
@@ -113,16 +117,17 @@ def draw_with_blend_and_clicks(
         rgb_mask = palette[mask.astype(np.uint8)]
 
         mask_region = (mask > 0).astype(np.uint8)
-        result = (
-            result * (1 - mask_region[:, :, np.newaxis])
-            + (1 - alpha) * mask_region[:, :, np.newaxis] * result
-            + alpha * rgb_mask
-        )
+        result = (result * (1 - mask_region[:, :, np.newaxis]) + (1 - alpha) *
+                  mask_region[:, :, np.newaxis] * result + alpha * rgb_mask)
         result = result.astype(np.uint8)
 
     if clicks_list is not None and len(clicks_list) > 0:
-        pos_points = [click.coords for click in clicks_list if click.is_positive]
-        neg_points = [click.coords for click in clicks_list if not click.is_positive]
+        pos_points = [
+            click.coords for click in clicks_list if click.is_positive
+        ]
+        neg_points = [
+            click.coords for click in clicks_list if not click.is_positive
+        ]
 
         result = draw_points(result, pos_points, pos_color, radius=radius)
         result = draw_points(result, neg_points, neg_color, radius=radius)
