@@ -1,9 +1,10 @@
-from .shortcut import ShortcutWindow
+from .shortcut import ShortcutWidget
+from .loading import LoadingWidget
 from .line import LineItem
 from .grip import GripItem
 from .bbox import BBoxAnnotation
 from .polygon import PolygonAnnotation
 from .scene import AnnotationScene
 from .view import AnnotationView
-from .create import *
 from .table import TableWidget
+from .create import (create_text, create_button, create_slider, creat_dock)
